package com.mycompany.app;

import static com.codeborne.selenide.CollectionCondition.allMatch;
import static com.codeborne.selenide.CollectionCondition.texts;
import static org.junit.Assert.assertTrue;

import java.time.Duration;
import java.util.Arrays;
import java.util.List;

import com.codeborne.selenide.*;
import org.junit.Test;

import static com.codeborne.selenide.Condition.*;


/**
 * Unit test for simple App.
 */
public class AppTest 
{
    AppTestPage home = new AppTestPage();

    @Test
    public void testURL() {
        home.open().assertUrl();
    }

    @Test
    public void testTitle() {
        home.open().assertTitle();
    }

    @Test
    public void testMenuLink() {
        home.open();
        home.getKulturaNavLink().click();
        String url = WebDriverRunner.url();
        assertTrue(url.contains("kultura"));
    }

    @Test
    public void testIfLogoExist() {
        home.open().getLogoLink().shouldBe(visible);;
    }

    @Test
    public void testIfNavLinksHaveCorrectText() {

        List<String> expectedLinks = Arrays.asList("NEWSY", "RECENZJE", "TEKSTY", "KULTURA", "WIDEO", "CZASOPISMO", "TECHNOLOGIE", "RETRO", "BAZA GIER", "NA LUZIE", "FORUM");
        ElementsCollection linksList = home.open().getNavLinks();
        linksList.shouldHave(texts(expectedLinks));
    }
    @Test
    public void testIfArticleLinkAndArticleTitleMatch() {
        home.open();
        SelenideElement articleLink = home.getArticleLink().should(exist);
        String articleLinkText = articleLink.text();
        articleLink.click();
        SelenideElement articleTitle = home.getArticleTitle().should(exist);
        articleTitle.shouldHave(text(articleLinkText));
    }

    @Test
    public void testIfSearchWorks() {
        home.open().getSearchLink().click();
        home.getSearchInput().val("aaaaa").pressEnter();
        home.getSearchInput().should(exist);

        ElementsCollection searchResults = home.getSearchResults();
        List<String> searchResultTexts = searchResults.texts();
        System.out.println(searchResultTexts);
        for (String str: searchResultTexts){
            assertTrue(str.matches("^.*(aaaaa|AAAAA).*$"));
        }
    }

}
